@@ -24,9 +24,9 @@ dcsn <- function(x, mu, sigma, gamma, nu, delta){
   if (is.matrix(delta) && ncol(delta) != length(nu))
     stop("incorrect 'delta'")
   for (i in 1:nrow(x)){
-   f1 <- pmnorm(0,nu,delta+gamma%*%sigma%*%t(gamma))
-   f2 <- pmnorm(as.vector(gamma%*%(x[i,]-mu)), nu, delta)
-   f3 <- dmnorm(x[i,], mu, sigma)
+   f1 <- pmvnorm(upper = rep(0,length(nu)),mean = nu,sigma = as.matrix(delta+gamma%*%sigma%*%t(gamma)))
+   f2 <- pmvnorm(upper = as.vector(gamma%*%(x[i,]-mu)), mean = nu, sigma = as.matrix(delta))
+   f3 <- dmvnorm(x = as.vector(x[i,]),mean = as.vector(mu), sigma = as.matrix(sigma))
    result[i] <- (f1^(-1))*f2*f3 
   }
   return(result)
